@@ -4,10 +4,10 @@ package Config::Simple::Conf;
 
 use strict;
 # Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.6 $' =~ /: ([\d\.]+)/);
+our $VERSION = $1 if('$Revision: 1.7 $' =~ /: ([\d\.]+)/);
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.6 2016/04/27 17:01:00 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.7 2016/05/01 03:10:13 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -410,7 +410,11 @@ sub _stage2 {
 							if(ref($conf->{$aa}->{$ab}) eq 'ARRAY'){
 								&_die("ERROR: the embedded key [$aa:$ab] in section [$sec] must be unique: " . join("; ", @{ $conf->{$aa}->{$ab} }));
 							} elsif($conf->{$aa}->{$ab}){
-								$conf->{$sec}->{$key}->[$i] =~ s/\[[^:]+\:[^\]]+]/$conf->{$aa}->{$ab}/g;
+								my ($raa, $rab) = ($aa, $ab);
+								$raa =~ s/(\W)/\\$1/g;
+								$rab =~ s/(\W)/\\$1/g;
+
+								$conf->{$sec}->{$key}->[$i] =~ s/\[$raa:$rab\]/$conf->{$aa}->{$ab}/gi;
 								$try++;
 							}
 						} elsif($conf->{$sec}->{$key}->[$i] =~ /\[([^\]]+)]/){
@@ -419,7 +423,10 @@ sub _stage2 {
 							if(ref($conf->{global}->{$aa}) eq 'ARRAY'){
 								&_die("ERROR: the embedded global key [$aa] in section [$sec] must be unique: " . join("; ", @{ $conf->{global}->{$aa} }));
 							} elsif($conf->{global}->{$aa}){
-								$conf->{$sec}->{$key}->[$i] =~ s/\[[^\]]+]/$conf->{global}->{$aa}/g;
+								my $raa = $aa;
+								$raa =~ s/(\W)/\\$1/g;
+
+								$conf->{$sec}->{$key}->[$i] =~ s/\[$raa]/$conf->{global}->{$aa}/gi;
 								$try++;
 							}
 						}
@@ -431,7 +438,11 @@ sub _stage2 {
 						if(ref($conf->{$aa}->{$ab}) eq 'ARRAY'){
 							&_die("ERROR: the embedded key [$aa:$ab] in section [$sec] must be unique: " . join("; ", @{ $conf->{$aa}->{$ab} }));
 						} elsif($conf->{$aa}->{$ab}){
-							$conf->{$sec}->{$key} =~ s/\[[^:]+:[^\]]+\]/$conf->{$aa}->{$ab}/g;
+							my ($raa, $rab) = ($aa, $ab);
+							$raa =~ s/(\W)/\\$1/g;
+							$rab =~ s/(\W)/\\$1/g;
+
+							$conf->{$sec}->{$key} =~ s/\[$raa:$rab\]/$conf->{$aa}->{$ab}/gi;
 							$try++;
 						}
 					} elsif(!ref($conf->{$sec}->{$key}) && $conf->{$sec}->{$key} =~ /\[([^\]]+)\]/){
@@ -440,7 +451,10 @@ sub _stage2 {
 						if(ref($conf->{global}->{$aa}) eq 'ARRAY'){
 							&_die("ERROR: the embedded key [$aa] in section [$sec] must be unique: " . join("; ", @{ $conf->{global}->{$aa} }));
 						} elsif($conf->{global}->{$aa}){
-							$conf->{$sec}->{$key} =~ s/\[[^\]]+\]/$conf->{global}->{$aa}/g;
+							my $raa = $aa;
+							$raa =~ s/(\W)/\\$1/g;
+
+							$conf->{$sec}->{$key} =~ s/\[$raa\]/$conf->{global}->{$aa}/gi;
 							$try++;
 						}
 					}
